@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -19,7 +17,7 @@ All these functions are not idempotent.
 =head1 SYNOPSIS
 
  use Rex::Commands::LVM;
- 
+
  my @physical_devices = pvs;
  my @volume_groups = vgs;
  my @logical_volumes = lvs;
@@ -32,11 +30,10 @@ All these functions are not idempotent.
 
 package Rex::Commands::LVM;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 require Rex::Exporter;
 use base qw(Rex::Exporter);
@@ -53,10 +50,10 @@ Get Information for all your physical volumes.
 
  use Data::Dumper;
  use Rex::Commands::LVM;
- 
+
  task "lvm", sub {
    my @physical_volumes = pvs;
- 
+
    for my $physical_volume (@physical_volumes) {
      say Dumper($physical_volume);
    }
@@ -106,10 +103,10 @@ Get Information for all your volume groups.
 
  use Data::Dumper;
  use Rex::Commands::LVM;
- 
+
  task "lvm", sub {
    my @volume_groups = vgs;
- 
+
    for my $volume_group (@volume_groups) {
      say Dumper($volume_group);
    }
@@ -163,10 +160,10 @@ Get Information for all your logical volumes.
 
  use Data::Dumper;
  use Rex::Commands::LVM;
- 
+
  task "lvm", sub {
    my @logical_volumes = lvs;
- 
+
    for my $logical_volume (@logical_volumes) {
      say Dumper($logical_volume);
    }
