@@ -1,8 +1,6 @@
 #
 # (c) Jean-Marie RENOUARD <jmrenouard@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -24,11 +22,10 @@ With this module you can define hostgroups out of an DBI source.
 
 package Rex::Group::Lookup::DBI;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex -base;
 use Carp;
