@@ -1,16 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Hardware::Network::Linux;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -415,7 +412,7 @@ sub _convert_cidr_prefix {
   my ($cidr_prefix) = @_;
 
   # convert CIDR prefix to dotted decimal notation
-  my $binary_mask = '1' x $cidr_prefix . '0' x ( 32 - $cidr_prefix );
+  my $binary_mask         = '1' x $cidr_prefix . '0' x ( 32 - $cidr_prefix );
   my $dotted_decimal_mask = join '.', unpack 'C4', pack 'B32', $binary_mask;
 
   return $dotted_decimal_mask;
