@@ -1,10 +1,9 @@
 package Rex::Hardware::VirtInfo;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex;
 use Rex::Helper::Run;
