@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Interface::Exec::OpenSSH;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.9.0'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex::Helper::SSH2;
 require Rex::Commands;
