@@ -1,17 +1,15 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Interface::Fs::Base;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
+use English qw(-no_match_vars);
 use Rex::Interface::Exec;
 use Rex::Helper::File::Spec;
 
@@ -163,7 +161,13 @@ sub cp {
   ($dest)   = $self->_normalize_path($dest);
 
   my $exec = Rex::Interface::Exec->create;
-  $exec->exec("cp -R $source $dest");
+
+  if ( $OSNAME =~ m/^MSWin/msx ) {
+    $exec->exec("copy /v /y $source $dest");
+  }
+  else {
+    $exec->exec("cp -R $source $dest");
+  }
 
   if ( $? == 0 ) { return 1; }
 
