@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Inventory::DMIDecode::MemoryArray;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.9.0'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex::Inventory::DMIDecode::Section;
 use base qw(Rex::Inventory::DMIDecode::Section);
@@ -37,4 +35,3 @@ sub new {
 }
 
 1;
-
