@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -17,7 +15,7 @@ This module is the logging module. You can define custom logformats.
  $Rex::Logger::format = '[%D] %s';
  # will output something like
  # [2012-04-12 18:35:12] Installing package vim
-   
+
  $Rex::Logger::format = '%h - %D - %s';
  # will output something like
  # srv001 - 2012-04-12 18:35:12 - Installing package vim
@@ -30,22 +28,17 @@ This module is the logging module. You can define custom logformats.
 
 package Rex::Logger;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
-#use Rex;
+use English qw(-no_match_vars);
+use Term::ANSIColor;
+
+use if $OSNAME eq 'MSWin32', 'Win32::Console::ANSI';
 
 our $no_color = 0;
-eval "use Term::ANSIColor";
-if ($@) { $no_color = 1; }
-
-if ( $^O =~ m/MSWin/ ) {
-  eval "use Win32::Console::ANSI";
-  if ($@) { $no_color = 1; }
-}
 
 my $has_syslog = 0;
 my $log_fh;
@@ -60,11 +53,6 @@ Setting this variable to 1 will enable debug logging.
 
 our $debug = 0;
 
-# we store the default handle to stderr
-# so that we can restore the handle inside the logging functions
-my $DEFAULT_STDERR;
-open $DEFAULT_STDERR, ">&", STDERR;
-
 =item $silent
 
 If you set this variable to 1 nothing will be logged.
@@ -102,7 +90,7 @@ sub init {
   eval {
     die
       if ( Rex::Config->get_log_filename || !Rex::Config->get_log_facility );
-    die if ( $^O =~ m/^MSWin/ );
+    die if ( $OSNAME =~ m/^MSWin/ );
 
     Sys::Syslog->use;
     openlog( "rex", "ndelay,pid", Rex::Config->get_log_facility );
@@ -125,9 +113,6 @@ sub info {
 
   return if $silent;
 
-  local *STDERR;
-  open STDERR, ">&", $DEFAULT_STDERR;
-
   if ( defined($type) ) {
     $msg = format_string( $msg, uc($type) );
   }
@@ -147,7 +132,7 @@ sub info {
   }
 
   if ( Rex::Config->get_log_filename() ) {
-    open( $log_fh, ">>", Rex::Config->get_log_filename() ) or die($!);
+    open( $log_fh, ">>", Rex::Config->get_log_filename() ) or die($OS_ERROR);
     flock( $log_fh, 2 );
     print {$log_fh} "$msg\n" if ($log_fh);
     close($log_fh);
@@ -186,9 +171,6 @@ sub debug {
   return if $silent;
   return unless $debug;
 
-  local *STDERR;
-  open STDERR, ">&", $DEFAULT_STDERR;
-
   $msg = format_string( $msg, "DEBUG" );
 
   # workaround for windows Sys::Syslog behaviour on forks
@@ -203,7 +185,7 @@ sub debug {
   }
 
   if ( Rex::Config->get_log_filename() ) {
-    open( $log_fh, ">>", Rex::Config->get_log_filename() ) or die($!);
+    open( $log_fh, ">>", Rex::Config->get_log_filename() ) or die($OS_ERROR);
     flock( $log_fh, 2 );
     print {$log_fh} "$msg\n" if ($log_fh);
     close($log_fh);
@@ -253,9 +235,6 @@ sub shutdown {
 
 }
 
-# %D - Date
-# %h - Host
-# %s - Logstring
 sub format_string {
   my ( $s, $level ) = @_;
 
@@ -265,7 +244,6 @@ sub format_string {
     && Rex::get_current_connection()->{conn}->server
     ? Rex::get_current_connection()->{conn}->server
     : "<local>";
-  my $pid = $$;
 
   my $line = $format;
 
@@ -273,7 +251,7 @@ sub format_string {
   $line =~ s/\%h/$host/gms;
   $line =~ s/\%s/$s/gms;
   $line =~ s/\%l/$level/gms;
-  $line =~ s/\%p/$pid/gms;
+  $line =~ s/\%p/$PID/gms;
 
   return $line;
 }
