@@ -1,12 +1,10 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Output;
 
-use strict;
+use v5.12.5;
 use warnings;
 
 my $handle;
@@ -17,7 +15,7 @@ END   { IPC::Shareable->clean_up_all; }
 
 use base 'Rex::Output::Base';
 
-our $VERSION = '1.9.0'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 sub get {
   my ( $class, $output_module ) = @_;
