@@ -1,16 +1,13 @@
 #
 # (c) Harm Müller <harm _DOT_ mueller _AT_ g m a i l _Dot_ com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Pkg::Arch;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex::Helper::Run;
 use Rex::Commands::File;
