@@ -1,18 +1,15 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Shared::Var::Scalar;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
 use Rex::Shared::Var::Common qw/__lock __store __retrieve/;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 sub TIESCALAR {
   my $self = { varname => $_[1], };
