@@ -1,16 +1,13 @@
 #
 # (c) Robert Abraham <robert@adeven.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Test::Base::has_stat;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex -base;
 use base qw(Rex::Test::Base);
