@@ -1,18 +1,15 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 #
 # this is a simple helper class for the get() function
 
 package Rex::Value;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.2'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 sub new {
   my $that  = shift;
